#
# spec file for package loki
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global loki_datadir /var/lib/loki
%global promtail_datadir /var/lib/promtail

Name:           loki
Version:        2.6.1+git.1658128747.6bd05c9a4
Release:        bp155.1.26
Summary:        Loki: like Prometheus, but for logs
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://grafana.com/loki
Source:         %{name}-%{version}.tar.bz2
Source1:        loki.service
Source2:        promtail.service
Source3:        sysconfig.loki
Source4:        sysconfig.promtail
Source99:       series
Patch0:         harden_promtail.service.patch
Patch1:         proper-data-directories.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  golang-packaging
BuildRequires:  systemd-devel
BuildRequires:  golang(API) = 1.17
Requires:       logcli = %{version}
Requires:       group(loki)
Requires:       user(loki)
Requires(post): %fillup_prereq
%systemd_ordering

###%%{go_nostrip}

%description
Loki is a horizontally-scalable, highly-available, multi-tenant log aggregation system inspired by Prometheus.

This package contains the Loki server

%package -n promtail
Summary:        Promtail Client
Group:          System/Monitoring

%description -n promtail
Loki is a horizontally-scalable, highly-available, multi-tenant log aggregation system inspired by Prometheus.

This package contains the Promtail client.

%package -n logcli
Summary:        LogCLI tool
Group:          System/Monitoring

%description -n logcli
Loki is a horizontally-scalable, highly-available, multi-tenant log aggregation system inspired by Prometheus.

This package contains the LogCLI command-line tool.

%prep
%autosetup -p1 %{name}-%{version}

%build
%define buildpkg github.com/grafana/loki/pkg/build
export CGO_ENABLED=0
export GOFLAGS="-mod=vendor -buildmode=pie -tags=netgo"
export GOLDFLAGS="-s -w -X %{buildpkg}.Version=%{version} \
                        -X %{buildpkg}.Revision=%{release} \
                        -X %{buildpkg}.Branch=NA \
                        -X %{buildpkg}.BuildUser=NA \
                        -X %{buildpkg}.BuildDate=NA"

go build -ldflags="$GOLDFLAGS" ./cmd/loki
go build -ldflags="$GOLDFLAGS" ./cmd/logcli
CGO_ENABLED=1 go build -ldflags="$GOLDFLAGS" ./clients/cmd/promtail

%install

# Service files for Loki and promtail
install -Dm644 %{SOURCE1} %{buildroot}%{_unitdir}/loki.service
install -Dm644 %{SOURCE2} %{buildroot}%{_unitdir}/promtail.service
install -Dm644 %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.loki
install -Dm644 %{SOURCE4} %{buildroot}%{_fillupdir}/sysconfig.promtail
install -dm755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcloki
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcpromtail

# Config files
install -Dm640 cmd/loki/loki-local-config.yaml \
    %{buildroot}%{_sysconfdir}/loki/loki.yaml
install -Dm640 clients/cmd/promtail/promtail-local-config.yaml \
    %{buildroot}%{_sysconfdir}/loki/promtail.yaml

# Binaries
install -dm755 %{buildroot}%{_bindir}
install -Dm755 loki %{buildroot}%{_bindir}
install -Dm755 promtail %{buildroot}%{_bindir}
install -Dm755 logcli %{buildroot}%{_bindir}

install -D -d -m 0750 %{buildroot}%{promtail_datadir} %{buildroot}%{loki_datadir}

%pre
%service_add_pre loki.service

%post
%fillup_only
%service_add_post loki.service

%preun
%service_del_preun loki.service

%postun
%service_del_postun loki.service promtail.service

%pre -n promtail
%service_add_pre promtail.service

%post -n promtail
%fillup_only -n promtail
%service_add_post promtail.service

%preun -n promtail
%service_del_preun promtail.service

%postun -n promtail
%service_del_postun promtail.service

%files
%license LICENSE
%doc README.md
%{_unitdir}/loki.service
%{_fillupdir}/sysconfig.loki
%{_bindir}/loki
%dir %{_sysconfdir}/loki
%config(noreplace) %attr(-,root,loki) %{_sysconfdir}/loki/loki.yaml
%{_sbindir}/rcloki
%dir %attr(-,loki,loki) %{loki_datadir}/

%files -n promtail
%{_unitdir}/promtail.service
%{_fillupdir}/sysconfig.promtail
%{_bindir}/promtail
%dir %{_sysconfdir}/loki
%config(noreplace) %{_sysconfdir}/loki/promtail.yaml
%{_sbindir}/rcpromtail
%dir %{promtail_datadir}/

%files -n logcli
%{_bindir}/logcli

%changelog
* Thu Jul 21 2022 ecsos@opensuse.org
- Update to version 2.6.1+git.1658128747.6bd05c9a4:
  * [release-2.6.x] Backport dskit, memberlist version updates to 2.6.x to support memberlist cluster labels and verification; re-vendor (#6693)
  * Fix per-tenant delete client (#6696) (#6698)
  * Docs: Fix bad links in the API section (#6688) (#6694)
  * Fix TIME_WAIT connection leak from queriers to compactor (#6681) (#6692)
  * avoid making delete requests if deletes are disabled for a user (#6583) (#6687)
  * Add client type as label (#6469) (#6685)
  * Handle duplicate registration of deletion metrics (#6446) (#6684)
  * Do not fail queries if compactor returns unexpected status code (#6552) (#6683)
  * Add API delete curl examples (#6680) (#6682)
  * added link to release notes page on releases page (#6639)
  * added link to release notes page (#6638)
  * updated date of the release and release notes (#6635)
  * Draft of release notes for loki 2.6. (#6546) (#6624)
  * 2.6 Backport: Promtail: Add text encoding conversion to file targets (#6395) (#6617)
  * Append .x to the versioned directories for the website sync (#6611) (#6613)
  * [release-2.6.x] CI/CD: Update documentation publishing workflows (#6607)
  * manually backported changes from #6386 (#6588)
  * Docs: Edits for several PRs that did not have a docs review (#6398) (#6575)
  * fix(documentation): correct spelling and scrape_config (#6454) (#6576)
  * Fix documentation of environment variable defaults (#6536) (#6577)
  * Docs: revise multi-tenancy prose (#6355) (#6578)
  * Docs: Add multi-tenant query curl examples (#6530) (#6563)
  * Add label_replace and literal expressions to instant query split by range (#6515) (#6559)
  * Fix panic in instant query splitting when using unwrapped rate (#6348) (#6557)
  * [release-2.6.x] Add unwrapped aggregation `rate_counter()` (#6556)
  * Sum values in unwrapped rate aggregation instead of treating them as counter (#6361) (#6555)
  * resolved merge conflict Docs: improve API docs (#6485)
  * Removing CHANGELOG entry (#6525)
  * Promtail: disable syslog tests which have expired certs (#6520)
  * Revert "Add cache usage statistics (#6317)"
  * bumped images/binaries version to 2.6.0
  * created section with loki version 2.6.0 in upgrading guide
  * updated CHANGELOG.md for the release 2.6.0 (#6506)
  * [release-2.6.x] Add TLS config to query frontend (#6498)
  * [k102] Backport Remove whole stream deletion mode (#6435) (#6477) (#6497)
  * Compactor: add per tenant compaction delete enabled flag (#6410) (#6476) (#6496)
  * Add more logging for delete requests (#6394) (#6473) (#6495)
  * Use correct counter when deleting lines (#6376) (#6472) (#6494)
  * Don't interupt the query path if deletes aren't available (#6368) (#6471) (#6493)
  * Backport #6413 and #6377 to k102 (#6422) (#6492)
  * Promtail: Add metrics for journal target (#6105)
  * TSDB/query-planning-groundwork (#6367)
  * cmd/loki: minor consistency patch (#6364)
  * Add total number of unique users involved in query readiness. (#6035)
  * operator: Allow optional installation of webhooks (#6363)
  * operator: Allow reduced tenant OIDC authentication requirements (#6362)
  * operator: Expose only an HTTPS gateway when in openshift-logging mode (#6288)
  * chore(fluentd): resolve rubocop failures (#6359)
  * Tsdb/index sampling endpoint (#6347)
  * loki-canary: Add support for client-side TLS certs for Loki connection (#6310)
  * operator: Add missing rbac to get/list/watch namespaces (#6303)
  * Update gopkg.in/yaml.v3 (#6284)
  * Support `series|labels` query_type in `logql_query_duration` (#6341)
  * Fix max series test loop that returns early (#6345)
  * [logql] don't try to execute a modified function that is not allowed by the AST (#6346)
  * Docs: Add changelog entry for configuration parameter name change (#6340)
  * TSDB/index-sampling-wiring (#6338)
  * Define a reason why the fifocache has evicted an item (#6335)
  * Set `MetricsNamespace` configurable for MemberlistKV module in Loki (#6330)
  * Update _index.md - an unofficial Loki client added (#6312)
  * Expose Memberlist status page on MemberlistKV module init (#6322)
  * Add multi_kv_config block to overrides configmap when multi kv is enabled (#6323)
  * Tsdb/index sampling (#6329)
  * always retry syncing index files from indexshipper when the index list cache is stale (#6327)
  * Add cache usage statistics (#6317)
  * Update delete integration test (#6192)
  * Use fake credentials in storage/chunk/storage tests (#6187)
  * Add licensing boiler plate in case we ever need it (#5251)
  * make index shipper read path handle range of tables by type of index (#6304)
  * copy boltdb-shipper cache changes from PR #6054 to generic index shipper (#6316)
  * Reduce to a single code path through sendBatches regardless of limit (#6216)
  * fix: allow promtail docker_sd_config to handle long log lines (#6256)
  * Fix delete cancellation timeout (#6285)
  * fixed type of the property in memberlist config (#6307)
  * Support tenant id from value (#6290)
  * We shouldn't modify the loki config at all if the memberlist ring is not (#6299) (#6308)
  * Tsdb/inverted index wiring (#6252)
  * Only consider an interval to have possible expired chunks if it overlaps a delete. (#6297)
  * exposes line length hist on distributors  (#6309)
  * do not initialize tsdb index store when using index gateway client for queries (#6305)
  * update loki-mixin json dashboards with latest jsonnet changes (#6306)
  * Look up config file in default locations (#6160)
  * Avoid line copy during LogQL line_format (#6104)
  * Improve write dashboard by removing unrelated route (#5853)
  * make tsdb store instance a singleton (#6273)
  * Import memberlist.libsonnet in loki.libsonnet. (#6294)
  * feat(fluentd): allow fluentd_thread label to be configurable (#6240)
  * Only delete data when WholeStreamDeletion or FilterAndDelete (#6286)
  * Document multi-tenant queries. (#5994)
  * operator: Add ruler config support (#6195)
  * Loki: add a run-once flag to the compactor (#6281)
  * fix boltdb shipper local query in logcli and support `fake` tenant (#6282)
  * operator: Add support for custom S3 CA (#6198)
  * Move ingester metrics around (#6275)
  * Snyk SBOM workflow add (#6274)
  * add metrics for tracking index shipper operations (#6278)
  * update drone signature (#6277)
  * Update docs for xk6-loki log formats (#6134)
  * Add duration filter unit test (#6271)
  * use tsdb config for initializing index gateway client (#6267)
  * Documentation: Explain --config.expand-env=true double slash with slash substitution (#6139)
  * Fix wording about pattern parser (#6264)
  * docs: Add Nomad deployment examples (#6258)
  * operator: Document how to connect Grafana to gateway (#6250)
  * Fix delete updates (#6194)
  * update drone branch match for 3 digit k release (#6263)
  * feat: Add support for Azure user assigned identity (#5891)
  * Memberlist related jsonnet (#6253)
  * docs: Default loki service port. (#6212)
  * Loki mixin: publish compiled version of the mixin (#6254)
  * Add jsonnet tools to build image (#6255)
  * chore(cache): Make exprimental messages more clear for cache. (#6219)
  * feat(ruler): support alert relabeling (#6220)
  * Docs: Reimplement PR 5649 on troubleshooting timeout errors (#6183)
  * Migrate Tool: Update to work with boltdb-shipper, improve logging output. (#6237)
  * Fix the signature for substr (#6236)
  * Add upgrade guide regarding azure container name change (#6118)
  * make boltdb-shipper use the generic indexshipper for managing index in object storage (#6226)
  * Add NRC in Adopters (#6242)
  * [Promtail] drop lines with malformed json (#6099)
  * Runtime reloadable config; ring migration setup (#6214)
  * Tsdb/inverted index (#6233)
  * Remove __name__ from label calls (#6229)
  * Improve labels computation during LogQL pipeline (#6110)
  * Fix label extraction pushdown on instant queries (#6215)
  * operator: Add rules support (#5986)
  * Docs: Hint about potential high cardinality metrics (#5603)
  * docs: describe ordering in http query results (#6024)
  * Docs: Fix design docs index page (#6008)
  * run store queries in ingester when using tsdb as index store (#6209)
  * prevents sharding avg and avg_over_time when their children arent shardable. (#6204)
  * docs: Fix broken link from unpack parser to pack stage (#6207)
  * doc(storage-example-configs): AWS single store configs (#6196)
  * Loki: Modifies TableManager to use IndexGateway ring (#5972)
  * Rename fudge_duplicate_timestamp to be increment_duplicate_timestamp (#6120)
  * creates a single tsdb for entire wal recovery (#6203)
  * copy all the fixes/improvements that went into boltdb-shipper that are missing from generic index-shipper (#6200)
  * operator: Changing GCP secret file path (#6199)
  * [loki microservices]: allow custom gateway server configuration (#6138)
  * Change deletion_enabled setting to deletion_mode (#6190)
  * Fix CHANGELOG entries. (#6193)
  * security: Redact credentials when marshalled to YAML (#6186)
  * Fix flaky gRPC server shutdown in tests (#6191)
  * tsdb index gateway (#6158)
  * strips out tenant label from LabelNames queries (#6181)
  * Add integration test for delete request (#6188)
  * Fixed reader to support both authentication and tenant-id at the same time. (#5719)
  * Fix typo in operator/docs/hack_operator_make_run.md (#6180)
  * tsdb creation supports fingerprint overrides (#6178)
  * skip empty object key returned by some s3 compatible storage while listing boltdb-shipper index (#6123)
  * fix(querier): Record `result` length after response validation. (#6176)
  * query-scheduler: Now proper support for `querier_forget_delay` (#6174)
  * ruler: Add support for alertmanager header authorization (#6136)
  * fix(tanka): add customizable common env vars (#6124)
  * Update SSL config for cassandra (#6145)
  * feat: support simple selection of labels in json expr parser (#6151)
  * Bump golangci/golangci-lint-action from 3.1.0 to 3.2.0 (#6170)
  * LogQL: add the `default` sprig template function to logql label/line formatter (#6163)
  * update auth header env variable usage help (#6169)
  * Add docs for updated deletion api (#5763)
  * specify logcli authorization header by flag (#6164)
  * corrected copy&paste error in list of labels (#6146)
  * Removed double space in Log (#6166)
  * tsdb query fixes (#6142)
  * operator: Add method to get authenticated from GCP (#6125)
  * Loki: When processing logs during tailing, don't reuse the query pipeline (#6152)
  * Fix certain binary expression queries by optimizing through push down (#6132)
  * Docs: redo PR 5109 (#6119)
  * Bump k8s.io/api, k8s.io/client-go, k8s.io/apimachinery from 0.22.7 to 0.23.6 (#6037)
  * Remove unused grpc health check endpoints (#6113)
  * loads previously created TSDBs into shipper on startup (#6117)
  * fix mutability bug with labels during tsdb flushing (#6116)
  * operator: Ruler enhancement proposal (#5985)
  * Tsdb/head wal feedback (#6107)
  * Document `/services` API endpoint (#6111)
  * do not increment sync operation count metric on per index set (#6109)
  * Update consistent hash ring docs with new index gateway ring (#6041)
  * Feat: add Baidu Cloud BOS as storage backends for Loki #4788 (#5848)
  * Serve correct status of ingester/distributor in gRPC healthcheck endpoint (#6094)
  * lambda-promtail: Add multi-tenancy support (#6102)
  * TSDB shipper + WAL (#6049)
  * clean up the pr diff message (#6098)
  * Revert "Loki: Change live tailing to only allow mutating the log line not the number of streams. (#6063)" (#6097)
  * Revert "Docs: fix pic location in `sources/fundamentals/architecture/deployment-modes.md` (#6089)" (#6093)
  * docs: update the labels timespan info (#6019)
  * Introduce coverage to PR pipelines (#5357)
  * `metrics.go` support for metadata queries(labels and series) (#5971)
  * table_manager: Change some level.Info() logging to level.Debug() (#6076)
  * Docs: fix pic location in `sources/fundamentals/architecture/deployment-modes.md` (#6089)
  * Remove nosiy "inflight" requests log entries (#6074)
  * Docs: remove Cortex references (#6079)
  * fix labeler (#6087)
  * renames skip -> ok in ProcessString (#6064)
  * Fix(query-frontend): LokiCodec encode/decode works correctly with label values endpoint (#6084)
  * Auto add labels on new pull request (#6065)
  * Add integration tests which test happy path (#5968)
  * Add UDP protocol support to Promtail's syslog target (#5790)
  * Loki: Change live tailing to only allow mutating the log line not the number of streams. (#6063)
  * Fix(query-frontend): `/label/<name>/values` endpoint to use right set of middlewares (#6072)
  * Bump actions/checkout from 2 to 3 (#5558)
  * Added NLog-Targets-Loki as unofficial C# client to Loki (#6061)
  * Fix broken link on deployment-modes.md (#6068)
  * allow more time for boltdb-shipper index syncs to finish (#6071)
  * promtail: Add support for exclusion patterns in `static_config` (#5943)
  * Update Loki reads/writes resources dashboards (#5765)
  * Add dot to some DNS address to reduce lookups (#5789)
  * Promoto policyRule to v1 (#6003)
  * Update libsystemd-dev from bullseye-backports for arm32 docker images, fixes (#5938) (#6012)
  * Bump github.com/minio/minio-go/v7 from 7.0.10 to 7.0.24 (#6007)
  * Use quiet flag in logcli tail.go. (#6033)
  * Add missing changelog entry for change introduced by PR 6034. (#6040)
  * boltdb shipper index list cache improvements (#6054)
  * Docs: Improve wording of getting started guide (#6060)
  * Add tailing metrics (#6059)
  * ignores reporting cancellations as errors in the usage-reporter module (#6058)
  * Improve index entries deduping and concurrency (#6055)
  * Add metrics to range mapper (#6030)
  * Improve batching in boltdb index (#6044)
  * Decrease log level for "failed to put to memcached" (#6018)
  * Add IndexGateway Query Readiness Duration panel to `Loki - Reads Resources` dashboard in production/loki-mixin (#6014)
  * Ensure proto definitions are formatted [2/2] (#6000)
  * docker-compose: Disable auth in Grafana (#5998)
  * Add filter parameter to rebound so lines can be deleted by the compactor (#5879)
  * operator: Merge gh index page with README.md to link to docs (#6048)
  * Improve series store index queries (#6045)
  * Upgrade inet.af/netaddr (#6046)
  * Docs: PR 5387 redo - Warn ECS users to avoid plain text creds (#6051)
  * Add query scheduler to "Read Resources" mixin dashboard (#6028)
  * Docs: revise getting started guide (#5939)
  * Minor fixes in docs/sources/api/_index.md (#5915)
  * Add better observability to queryReadiness (#5946)
  * Loki: Add a configurable ability to fudge incoming timestamps for guaranteed query sort order when receiving entries for the same stream that have duplicate timestamps. (#6042)
  * Revendor `grafana/tail` to fix promtail symlink behavior (#6034)
  * Remove empty match within concat of regex (#6026)
  * Disable calling new index-gateway client's API. (#6025)
  * operator: logerr v2 update (#5987)
  * Remove references to cortex (#6015)
  * migrated gelfTarget to go-gelf/v2 library that contains fix for chunked messages (#5992)
  * Add buf to the build image (#5785)
  * Use new build image 0.20.3 (#5904)
  * Invalidate caches on delete (#5661)
  * Querier: prevent unnecessary calls to ingesters (#5984)
  * Add string representation of boltdb shipper mode (#5982)
  * fix: remove typo in gateway config (#5981)
  * Call correct method on index store (#5979)
  * Do not parse string of empty matchers (#5980)
  * Add changelog entry for split by range of instant queries (#5966)
  * redact s3 credential values when printing config to logs (#5961)
  * Loki: Make DNS resolver configurable in Gateway (#5973)
  * Add query filtering to the tailer (#5969)
  * Fix query filtering (#5951)
  * Other: Update pr template (#5885)
  * Other: trigger build of loki-build-image:0.20.3 (#5924)
  * fix index gateway chunk refs response (#5957)
  * operator: Bump operator-sdk to v1.19.1 (#5929)
  * Other: Improve check-drone-drift script (#5925)
  * common index set should not expire before any of the user index sets (#5954)
  * [promtail] Add a log message stating that client level stream lag labels are deprecated (#5850)
  * chore: Fix flaky test with `TestSingleIdx`. (#5947)
  * Docs: Fix typo in 429 exceeded rate limit error message (#5944)
  * build generic index shipper to be shared between boltdb-shipper and tsdb-shipper (#5705)
  * Query filtering in the ingester and storage (#5629)
  * store: fix bug in getting chunk ids from ingesters when using boltdb-shipper (#5945)
  * Update _index.md (#5934)
  * Update CHANGELOG.md (#5935)
  * Add SIG operator team to governance doc (#4977)
  * Fix SSD Docker installation (#5916)
  * Loki: Fix issue with recent change to flush code (#5932)
  * Implements TSDB Head (#5864)
  * Fixes the index-gateway when using the ring (#5923)
  * Include tenant ID label in label values. (#5908)
  * Only run boltdb-shipper when appropriate. (#5917)
  * Fixes a panic when response is nil in the index-gw (#5910)
  * operator: Do not include non-static labels in pod selectors (#5907)
  * operator: Align PVC storage size requests for all lokistack t-shirt sizes (#5893)
  * Loki: Flush chunks one at a time (#5894)
  * Update golangci-lint in build image (#5901)
  * Introduce a more scalable index-gateway API. (#5892)
  * Do not use boltdb-shipper if no ring or address are given. (#5902)
  * Raise version of build image correctly (#5900)
  * docs: fix query_ingester_only config (#5873)
  * Enable tenant ID selection for multi-tenant queries. (#5821)
  * Upgrade golang version to v1.17.9 (#5899)
  * Add a Ring to IndexGateway (#5358)
  * loki: Fix common config net interface name overwritten by ring common config (#5888)
  * Update _index.md (#5887)
  * Update _index.md (#5871)
  * operator: Update Loki operand to v2.5.0 (#5884)
  * Add more function comments to the rangemapper implementation (#5861)
  * remove excessive underscore from `dockerLabelLogStream` (#5890)
  * Return HTTP 400 when multiple tenants are present in push. (#5800)
  * Docs: Improve the new schema docs (#5869)
  * Update dskit to v0.0.0-20220331160727-49faf69f72ca. (#5881)
  * document flag for disabling broad index queries (#5880)
  * [promtail] Mark promtail single client config flags and config file block as deprecated (#5842)
  * GCS: refactor creation of http client (#5838)
  * Minor fix in docs/sources/logql/log_queries.md (#5868)
  * Bump actions/setup-go from 2 to 3 (#5859)
  * Improve kafka discovery test. (#5860)
  * Fix flaky test (#5307)
  * Docs: Add usage reporting section to 2.5 release notes (#5865)
  * add some docs for working with the storage schema (#5863)
  * fix: adopters link for Heureka Group (#5862)
  * Moves TSDB to the stores package. (#5852)
  * Fix wrong indentation in example config (#5828)
  * promtail: Add ActiveTargets method (#5839)
  * Add Heureka Group to adopters (#5846)
  * lambda-promtail: fix typos in CloudFormation and Terraform files. (#5749)
  * Refactoring of the Loki storage (#5833)
  * Makefile: run lint and tests with default garbage-collection (#5841)
  * usagestats tests: don't check unpredictable number (#5840)
  * Fixes deduping when multiple timestamp are equal (#5799)
  * gcs client: use fake credentials in unit test (#5834)
  * TestPromtail: avoid hanging when test fails midway (#5837)
  * incorporate feedback on merged pr #5830 (#5831)
  * improve mutex locking when writing index in boltdb-shipper (#5830)
  * [Optimization] boltdb: reduce the code block affected by the lock tablesMtx in the TableManager.query() function. (#5829)
  * Split by range of instant queries (#5662)
  * try fixing drone again (#5826)
  * update drone to push images on tagged builds (#5824)
  * 2.5 changelog, release notes, and upgrade guide (#5819)
  * fix missing file during rpm and deb packaging step (#5818)
  * Tsdb/compaction (#5783)
  * storage: make Azure blobID chunk delimiter configurable (#5777)
  * Promtail docs: fix metrics stage. (#5740)
  * Add X4B as an adopter (#5795)
  * Return bad request for multi-tenant tail. (#5792)
  * fix boltdb-shipper doc (#5796)
  * Update alpine images to 3.15.4 (#5780)
  * Add a DeletionMode config variable (#5481)
  * Allow promtail to push RFC5424 formatted syslog messages (#5715)
  * golangci-lint: Check for pointers to enclosing loop variables (#5775)
  * Build: update package for fuzzer after refactoring (#5776)
  * Loki: Add more details about usage reporting to the docs and default config files. (#5767)
  * Loki: Revert #4845 which changed the format of errors from the API (#5772)
  * Docs: Document Promtail global rate limiting (#5737)
  * Increase flush_op_timeout to 10m, 10s is often much too short for a big WAL replay which can generate a lot of chunks very quickly. (#5768)
  * use an empty registry when setting up the logger for the push server (#5761)
  * operator: Update Prometheus go client to resolve CVE-2022-21698 (#5748)
  * [new] promtail pipeline:  Promtail Rate Limit stage #5048 (#5051)
  * ensure tsdb is sorted by hash then labelset (#5746)
  * operator: change uuids to tenant name in doc (#5739)
  * fixes existing test case and adds more (#5687)
  * Update MultiTenantQuerier `Series()` and `Label()` to use `user.InjectOrgID()` instead of `user.InjectUserID()` (#5735)
  * operator: Add missing label matcher for openshift logging tenant mode (#5729)
  * Implement `Series` and `Label` for MultiTenantQuerier (#5566)
  * Revert changes to generated assets_vfsdata.go. (#5728)
  * Use dskit/tenant intead of loki/pkg/tenant. (#5724)
  * Update fluent-bit output name (#5711)
  * Fixed Getting started docs error (#5504)
  * Docs: add an empty v2.5 release notes section (#5533)
  * Promtail: Fix retry/stop when erroring for out of cloudflare retention range (e.g. over 168 hours old) (#5698)
  * logcli: Remove port from TLS server name when provided in --addr (#5477)
  * Update docker repo to grafana/loki-query-tee (#5716)
  * Assert that push values tuples consist of string values (#5685)
  * Mark GELF support in Promtail as experimental (#5697)
  * Build querytee image as part of CI pipeline (#5700)
  * Update Fluent Bit docs (#5402)
  * operator: Fix immediate reset of degraded condition (#5691)
  * Update retention.md (#5706)
  * Promtail: Rename config name limit_config to limits_config (#5707)
  * operator: Update operator-sdk to 1.18.1 (#5704)
  * operator: Replace frontend_worker parallelism with match_max_concurrent (#5693)
  * operator: Fix multiple storage support for boltdb_shipper and schema (#5699)
  * Move promtail StreamLagLabels config to upper level config.Config (#5686)
  * operator: make replicationFactor optional (#5701)
  * Require unique client configs when there are multiple clients. (#5688)
  * operator: Update to Go 1.17 (#5695)
  * operator: Document how to connect to LokiStack gateway component (#5615)
  * operator: Update Loki operand to 2.4.2 (#5655)
  * Fix bug with new promtail stream lag metric where labels might not be (#5675)
  * Fix debug image by updating Delve version (#5673)
  * Speed up re-labelling in multi-tenant queries. (#5663)
  * Add Digitalist as adopter (#5596)
  * Fix broken Fluentbit / Fluentd plugin doc links (#5664)
  * operator: Update developer addons (#5599)
  * operator: Adding instructions to respond to alerts (#5579)
  * TSDB Index reuses slices, adds pools (#5630)
  * Tsdb/hash order (#5631)
  * Support limits in multi-tenant queries. (#5626)
  * Add inflight requests metric to scheduler (#5658)
  * operator: Update CSV to point to candidate channel and use openshift-operators-redhat ns (#5640)
  * operator: Document how to connect to distributor component (#5551)
  * Preserve interval parameter when splitting queries by time (#5622)
  * Introduce a ChunkRef type as part of logproto  (#5643)
  * improve boltdb-shipper logging to help debug index query latency issues (#5651)
  * Remove more chunkstore and schema version below v9 (#5650)
  * Remove more unused code (#5638)
  * debug log number of index entries cached and retrieved from the cache per index query (#5642)
  * Remove benchmark cron job. (#5641)
  * Remove unused code from cortex (#5633)
  * Remove unused storage gateway references (#5627)
  * Tsdb/sharding-benchmarks (#5628)
  * operator: Use tenant name as id for mode openshift-logging (#5624)
  * [Frontend] Log Result Cache (#5502)
  * [promtail] Refactor promtail client metrics so that we can't have duplicate metrics collected for the lag metric. (#5521)
  * Test multi-tenant context propagation. (#5620)
  * operator: Use recommended labels for LokiStack components (#5621)
  * Query Filtering -- Querier (#5482)
  * Refactor LogQL syntax into its own package (#5539)
  * operator: Use lokistack name as prefix for owned resources (#5607)
  * Update Prometheus to latest (#5545)
  * Print stacktrace to stderr for easier readability (#5616)
  * Replace `PromQL` -> `LogQL` wordings in Querier (#5602)
  * Tsdb/sharding (#5600)
  * Tsdb/multi idx (#5598)
  * Add RBAC for Prometheus service discovery to Loki component metrics (#5588)
  * canary: Adds locking to prevent multiple concurrent invocations of `confirmMissing` from clobbering each other (#5568)
  * bounds utility for tsdb lib (#5593)
  * more tsdb benchmarks + updates script to work with incompatible branches (#5590)
  * Compactor improvements (#5587)
  * Make Loki adopters visible in README (#5586)
  * cleanup common index source files at the end while compacting index with boltdb-shipper (#5585)
  * store tsdb bounds (#5582)
  * build a new batch while starting to process a bucket (#5580)
  * Tsdb/index interface (#5577)
  * operator: Change endpoints for generated liveness and readiness probes (#5576)
  * operator: Reorder changelog in descending order (#5572)
  * Docs: update documentation about "limit" param (#5540)
  * Fix frontend-worker error message (#5567)
  * operator: Add steps to check and run the prometheus rule tests in GitHub action (#5564)
  * Fix service monitor's server name for operaror metrics (#5560)
  * Refactor sharding engine to downstream engine (#5546)
  * operator: Add flag to create Prometheus rules (#5345)
  * Loki mixin: add DiskSpaceUtilizationPanel (#5552)
  * Docs: Fix broken link to "Matching IP addresses" (#5550)
- Rebase proper-data-directories.patch.
- Add missing paths into proper-data-directories.patch.
* Thu Jun 30 2022 Marcus Rueckert <mrueckert@suse.de>
- also track quilt series file to make it easy to setup a quilt
  working copy
* Thu Jun 30 2022 Marcus Rueckert <mrueckert@suse.de>
- also make the config file permissions more strict:
  /etc/loki/loki.yaml     root:loki u=rw,g=r,o=
  /etc/loki/promtail.yaml root:root u=rw,g=r,o=
* Thu Jun 30 2022 Marcus Rueckert <mrueckert@suse.de>
- default configs reference paths in /tmp. move those to proper
  places:
  loki data dir: /var/lib/loki loki:loki u=rwx,g=rx,o=
  promtail data dir: /var/lib/promtail root:root u=rwx,g=rx,o=
  Existing configs will not be updated
  Added proper-data-directories.patch
* Mon May 23 2022 ecsos@opensuse.org
- Update to version 2.5.0+git.1649366683.2d9d0ee23:
  * try fixing drone again (#5826) (#5827)
  * update drone to push images on tagged builds (#5824) (#5825)
  * [release-2.5.x] 2.5 changelog, release notes, and upgrade guide (#5823)
  * fix missing file during rpm and deb packaging step (#5818) (#5822)
  * Update Fluent Bit docs (#5402) (#5805)
  * Fixed Getting started docs error (#5504) (#5806)
  * Docs: update documentation about "limit" param (#5540) (#5807)
  * Make Loki adopters visible in README (#5586) (#5808)
  * Update retention.md (#5706) (#5809)
  * Update fluent-bit output name (#5711) (#5810)
  * operator: Document how to connect to distributor component (#5551) (#5811)
  * Fix broken Fluentbit / Fluentd plugin doc links (#5664) (#5812)
  * Mark GELF support in Promtail as experimental (#5697) (#5813)
  * Docs: Document Promtail global rate limiting (#5737) (#5814)
  * Release 2.5.x (#5817)
  * Preserve interval parameter when splitting queries by time (#5622) (#5815)
  * remove extra stuff accidentally added to changelog
  * [new] promtail pipeline:  Promtail Rate Limit stage #5048 (#5051) (#5793)
  * update docs references from 2.4 -> 2.5
  * Update changelog for 2.5 release
  * Promtail: Rename config name limit_config to limits_config (#5707) (#5788)
  * Update Prometheus to latest (#5545) (#5787)
  * Update alpine images to 3.15.4 (#5780) (#5786)
  * Fix frontend-worker error message (#5567) (#5781)
  * Promtail: Fix retry/stop when erroring for out of cloudflare retention range (e.g. over 168 hours old) (#5698) (#5782)
  * use an empty registry when setting up the logger for the push server (#5761) (#5762)
  * Increase flush_op_timeout to 10m, 10s is often much too short for a big WAL replay which can generate a lot of chunks very quickly. (#5768) (#5771)
  * Loki: Revert #4845 which changed the format of errors from the API (#5772) (#5774)
  * Loki: Add more details about usage reporting to the docs and default config files. (#5767) (#5778)
  * creating release branch for 2.5.x from k88
  * cleanup common index source files at the end while compacting index with boltdb-shipper (#5585)
  * build a new batch while starting to process a bucket (#5580)
  * updates clusterrole and clusterrolebinding apiVersions in promtail.sh (#5547)
  * Fix path to binary in Dockerfile for querytee (#5537)
  * update loki go version to 1.17.8 (#5543)
  * regexp filter: use modified package with optimisations (#5542)
  * Update vectorAggEvaluator to fail for expressions without grouping (#5544)
  * Update grafana/regexp package to reject very deeply nested regexps (#5541)
  * Change usagestats expvars so they can be set twice (#5515)
  * Revert "metrics: Add `user` label to `worker_inflight_queries` (#5485)" (#5534)
  * loki mixin: make labelsSelector in loki chunks dashboards configurable (#5536)
  * loki mixin: use labels selector for loki chunks dashboard (#5535)
  * Support `SelectLogs` and `SelectSamples` in multi-tenant querier. (#5517)
  * [bugfix] fix nil pointer (#5527)
  * Update metric_queries.md (#5525)
  * Fix orphaned metrics in the file tailer (#5497)
  * Update Pub/Sub docs section (#5205)
  * fix broken index gateway benchmark due to missing limits (#5520)
  * Lambda-promtail: add basic auth support (#5503)
  * Update out_loki.rb (#5512)
  * [operator] Update ClusterServiceVersion to add missing configurations (#5467)
  * Fix port name used for GRPC service (#5489)
  * Add prefix to vault path (#5510)
  * Fix test (#5509)
  * Remove extra param in call for inflightRequests metric (#5507)
  * Change path for deploy config (#5506)
  * Bump google.golang.org/api from 0.63.0 to 0.65.0 (#5135)
  * Align usage report config with Grafana (#5406)
  * Stub multi tenant querier. (#5490)
  * Replacing cortex_bigtable* metrics with the correct loki_bigtable* metrics (#5500)
  * Changelog: Include #5409 (#5480)
  * CI: moving autodeploy configuration secret to new location (#5491)
  * Bump golangci/golangci-lint-action from 2 to 3.1.0 (#5488)
  * metrics: Add `user` label to `worker_inflight_queries` (#5485)
  * Docs: Fix links and formatting of HTTP API page (#5498)
  * Docs: fix link reference to "Step vs Interval" section. (#5495)
  * initialize overrides when running index gateways which is required to run them (#5496)
  * mount overrides volume to index gateways (#5493)
  * Document all support API timestamp formats. (#5439)
  * Fix potential deadlock in the table manager (#5472)
  * per user index query readiness with limits overrides (#5484)
  * Rounds chunk bytes to kb in tsdb and includes benchmarking script (#5479)
  * promtail/targets/syslog: Enable best effort parsing for Syslog messages (#5409)
  * Fixes Reads dashboard boltdb panels. (#5475)
  * Stream query responses from boltdb index client (#5468)
  * Fix circular dependencies (#5420)
  * Disable sharding of count/avg when labels are mutated (#5474)
  * Fixes ingester sample deduping (#5470)
  * Add support for additional storage backends in operator (#5432)
  * boltdb shipper index gateway client improvements (#5456)
  * Update _index.md (#5458)
  * Fix two remote_timeout configs in ingester_client block (#5418)
  * logproto: Add deprecated annotation to LegacySample and LegacyLabelPair (#5454)
  * use the defined querypages callback in all the types implementing QueryPages function from IndexClient interface (#5463)
  * Change default installation namespace on OpenShift (#5441)
  * Do not insert point when missing when sharding (#5444)
  * Update loki-mixin/dashboard-loki-operational queries to correctly display Loki metrics for Memcache and Consul (#5462)
  * Tsdb/idempotent builder (#5424)
  * pkg/ruler/base: Add external_labels option (#5450)
  * Fix operational dashboard (#5448)
  * add a metric for tracking the duration it took to sync the tables in queriers/index-gateways (#5446)
  * Adds a tool for converting boltdb->tsdb and benchmarking queries (#5430)
  * do not send grpc responses concurrently from index-gateway (#5445)
  * Build: simplify make targets to just run every time (#5411)
  * Parse duration expressions in accordance with promql (#5275)
  * set match_max_concurrent true by default (#5435)
  * jsonnet: move boltdb-shipper configs set as compactor args to yaml config (#5393)
  * Do not use WaitGroup context for StepEvaluator (#5425)
  * Use output plugin grafana-loki (#5386)
  * Correctly sets hash value for headblock iterator (#5423)
  * Adds bytes and entries to chunk metadata in tsdb (#5414)
  * remove promtail_log_entries_bytes_bucket (#5377)
  * Lambda-promtail: Enhance lambda-promtail to support adding extra labels from an environment variable value (#5359)
  * Revert to working version of Azure client (#5413)
  * Run `make drone` to use the new build image (#5368)
  * Update dskit version (#5392)
  * Fixes double metrics registration in reporting (#5407)
  * Experimental TSDB index (#5376)
  * Add the total number of subqueries to query statistics (#5397)
  * [operator] Add degraded condition when gateway is enabled and tenants spec is nil (#5383)
  * Cleaning up deploy-example-secret.sh (#5374)
  * Fix Azure issue where 404 not recognized (#5399)
  * Logql: Correct grouping type in pkg/logql/expr.y (#5306)
  * Add more context to tailer-> ingester connect error. (#5394)
  * Loki: include the component in metrics.go log line (#5379)
  * Verify that drone.yml was updated. (#5396)
  * add more context to logs, improve comments for clarity in boltdb-shipper code (#5341)
  * Fixes a flaky hedging test. (#5389)
  * cleanup common index set after cleaning up all the user index sets (#5372)
  * updated documentation for xk6-loki extension (#5321)
  * Fixes memberlist usage report (#5369)
  * Build and publish build image. (#5322)
  * Improve report usage to never fail (#5364)
  * Add usage report into Loki. (#5361)
  * Ruler: Rule group not found API message (#5362)
  * add a ms instead of ns to end time of the rebound chunk interval (#5351)
  * fix rounding of time to milliseconds (#5352)
  * Speed up `EntrySortIterator` by 20%%. (#5318)
  * Test `LegacySample` and `LegacyLabelPair` compatibility. (#5313)
  * fix changelog issue reference to lambda-promtail (#5347)
  * Fix apply retention issue (#5342)
  * Delete docs/sources/copyright directory (#5325)
  * Revert "Simplify code for write path in distributor (#5248)" (#5337)
  * Makes `tailer.droppedStreams` slice bounded. (#5334)
  * filters: use faster regexp package (#5315)
  * Release entryBufferPool once (#5324)
  * lambda-promtail: Add ability to ingest logs from S3 (#5065)
  * Docs: remove "regular" from string definition (#5309)
  * Documentation for load testing Loki with xk6-loki (#5182)
  * Simplify code for write path in distributor (#5248)
  * Fixes log deduplication when mutating Labels using LogQL (#5289)
  * Logql/parallel binop (#5317)
  * Add tooling for local k3d clusters under tools/dev (#5272)
  * added upgrade notes (#5311)
  * Update promtail to support duration string formats (#5290)
  * changed logic to respond with '500 Internal Server Error' if rpc error with code 'Cancelled' happened.
    it's made to allow loki to retry the request to the querier instead of returning '499 The request was
    cancelled by the client.' back to the client. (#5297)
  * storage: update azure blobstore client to use new sdk (#5302)
  * Fix transitive dependency error (#5308)
  * less opaque chunk keys on fs with v12 (#5291)
  * cleanup: consolidate util strings contain functions (#5304)
  * Implement `LegacySample`, `LegacyLabelPair` proto messages (#5301)
  * Fix `go.mod` path of operator (#5287)
  * better logic for when to shard wrt disabled lookback (#5303)
  * fix a panic in index-gateway caused by double closing of a channel (#5298)
  * Fix Promtail watching deadlock (#5283)
  * Link `replace` pipeline stage to doc (#5200)
  * Write Promtail position file atomically. (#5266)
  * Restart Docker target if stopped. (#5280)
  * Refactor HeapIterator into Merge and Sort Iterator. (#5281)
  * logstash: re-add bundle update and update bundler (#5284)
  * Revert "Adding a docs page that helps users understand memberlist a bit more (#5186)" (#5286)
  * Cleanup `util/validation` code. (#5285)
  * add some timing to the logs for downloading and opening index tables (#5042)
  * Auto-expire old items from FIFO cache (#5148)
  * Adding a docs page that helps users understand memberlist a bit more (#5186)
  * Update local configs to fix issues with incorrect addresses (#5207)
  * Promtail docs: Fix link to `unpack` LogQL documentation (#5274)
  * Return early if push payload does not contain data (#5229)
  * Remove `cortex` references from `go.mod` and makefile (#5269)
  * Copy `cortex/pkg/storage/bucket` package dependency into Loki (#5258)
  * Fix transitive dependency failure while building logstash plugin (#5268)
  * feat(promtail): fix TargetManager.run() not exit (#5238)
  * Remove `cortexpb` dependency from Loki packages. Use only `logproto` now. (#5264)
  * Logstash: Add config option which allows seting up an allowlist for labels to be mapped to Loki (#5244)
  * Fork `cortex/pkg/util` into Loki (#5257)
  * Ingester: remove the labelFilter (#5262)
  * use default retention period to check user index may have expired chunks when user does not have custom retention (#5261)
  * fluent-bit: Attempt to unmarshal nested json. (#5223)
  * Refactor/remove global splitby (#5243)
  * Copy `cortex/pkg/configs` package dependency into Loki (#5139)
  * Copy `cortex/pkg/ingester/client` package dependency into Loki (#5164)
  * Get rid of Cortex chunk. (#5239)
  * Push: add deflate compression in post requests (#5249)
  * refactor: use `T.TempDir` to create temporary test directory (#5253)
  * v12 chunk format handling in retention (#5254)
  * Fix docker plugin build (#5240)
  * Update Go version to latest and bump build image version (#5250)
  * Update _index.md (#5241)
  * skip glob search if path is an existing file and not a directory (#5246)
  * Lock consistencyMtx outside locking chunkMtx (#5210)
  * Update _index.md (#5159)
  * Remove ErrStreamMissing (#5234)
  * Update loki-mixin gcs queries in the Loki operational dashboard (#5232)
  * Start refactor of storage (chunks) clients metrics into structs (#5057)
  * Fix `cortexpb` -> `logproto` rename in some tests (#5231)
  * [querier] Abort a query in limitedRoundTripper if parallelism is 0 (#5190)
  * Bump logstash plugin gem (#5230)
  * Provide Docker target and discovery in Promtail. (#4911)
  * Improve docs on how to install logcli from source (#5126)
  * Add `MaxSurge` and `MaxUnavailable` strategy to all Loki k8 workloads. (#5227)
  * Copy `cortex/pkg/cortexpb` package dependency into Loki (#5151)
  * Copy `cortex/pkg/prom1` package dependency into Loki (#5196)
  * Update to Unofficial clients for JS (#5180)
  * Addition of cortex' queryrange tests (#5183)
  * Default max_outstanding_per_tenant to 2048 (#5204)
  * [instrument] cache: add tracing instrumentation when error !=nil (#5202)
  * Update Loki Team members in the Governance doc. (#5219)
  * fix broken boltdb-shipper test (#5222)
  * step align start and end time of the original query while splitting it (#5217)
  * per user index changes on the write path (#5193)
  * Copy `cortex/pkg/chunk/purger` package dependency into Loki (#5169)
  * Update docker.md (#5213)
  * Remove instance level streams lock (#5179)
  * Chore: Add pkg/util/log package (#5187)
  * [enhancement] querier : Add "query_memory_only" to make loki have option to rely only on memory availability like google monarch. (#5093)
  * changes on read path for supporting per user index with boltdb-shipper (#5073)
  * add objects list caching for boltdb-shipper index store to reduce object storage list api calls (#5160)
  * Remove temporary ruler ring key fix (#5189)
  * log headblock conversion error during replay cleanup (#5185)
  * Support `X-Query-Tags` in LogCLI (#5145)
  * align metric queries by step and other queries by split interval (#5181)
  * Avoid splitting large range vector aggregation. (#5172)
  * Move VerifyConfig after PrintConfig and LogConfig (#5149)
  * Handle `context` cancellation in some of the `querier` downstream requests (#5178)
  * Copy `cortex/tools/querytee` package dependency into Loki (#5165)
  * Support "POST" method for distributor ring (#5171)
  * Fix promtail deadlock (#5170)
  * Package logcli as rpm and deb. (#4667)
  * Add nil check for Ruler BasicAuth config. (#5168)
  * Fix encoding error in fluentd client (#5163)
  * Retry pulling Cloudflare logs after a stream error (#5158)
  * revert operator's loki-config changes (#5155)
  * [optimization] cache prometheus : fix "loki_cache_request_duration_seconds_bucket" ‘status_code’ label always equals "200" (#4891)
  * Docs: Update memory ballast documentation (#5106)
  * Ruler: Fix remote write basic auth credentials (#5144)
  * Fix broken `template_variable` doc link (#4960)
  * Remove unused `storegateway` base (#5141)
  * Fixes operational dashboard and add azure. (#5127)
  * Fix test in retention/expiration_test.go on slow machines (#5137)
  * add jsonnet for simple scalable deploymnet (#5138)
  * Querier worker/inflight metrics (#5124)
  * Jsonnet: Let compactor access the runtime_config (#4855)
  * Copy `cortex/pkg/querier` package dependency into Loki (#5122)
  * Document query limit parameter default. (#5133)
  * Bump github.com/klauspost/compress from 1.13.6 to 1.14.1 (#5134)
  * Bump github.com/fatih/color from 1.12.0 to 1.13.0 (#5111)
  * Fix cancel issue between Query Frontend and Query Schdeduler (#5113)
  * remove split_queries_by_interval validation (#5125)
  * Add missing forked gateway tests (#5118)
  * Update to 2.4.2 release (#5121)
  * Copy `cortex/pkg/querier/stats` package dependency into Loki (#5047)
  * Docs: Draft 2.4.2 release notes (#5105)
  * Copy querier subpackages dependency into Loki (#5068)
  * Copy `cortex/pkg/ruler` package dependency into Loki (#5089)
  * fluentd: Fix bug that caused lines to be dropped when containing non utf-8 characters (#5107)
  * Docs: Fix documentation with correct default values and add missing options (#4792)
  * Update Docker compose example (#4996)
  * Fixes HTTP2 removal for GCS (#5103)
  * update helm docs, add simple scalable (#4925)
  * Enable merge union strategy for CHANGELOG.md. (#5102)
  * improve default config values (#5077)
  * Bump github.com/pierrec/lz4/v4 from 4.1.7 to 4.1.12 (#5100)
  * better defaults for flush queue parallelism (#5091)
  * Bump github.com/mitchellh/mapstructure from 1.4.2 to 1.4.3 (#5101)
  * Fixes metric name for hedging object store requests (#5098)
  * [enhancement] querier cache: WriteBackCache should be off query path (#5083)
  * Handle `context` cancellation in some of the `querier` downstream requests (#5080)
  * LogQL: add __line__ function to | line_format template (#4879)
  * Add the option to configure memory ballast for Loki (#5081)
  * Copy `cortex/pkg/storegateway` package dependency into Loki (#5088)
  * Removes split-by upstream validation (#5087)
  * Chore: Upgrade to latest Cortex (#5085)
  * Fix deadlock in disconnecting querier (#5063)
  * Fixes a possible cancellation issue (#5075)
  * Docs: Revise hedging configuration block descriptions (#5069)
  * expand ruler ring section to add num_tokens property (#4899)
  * Simpler new chunk key v12 (#5054)
  * compactor changes for building per user index files in boltdb shipper (#5026)
  * Add an egress bytes total metric to the azure client. (#5067)
  * Define Ingester interface to enable wrapping. (#4988)
  * [new] promtail: add readline rate limit (#5031)
  * Fix race conditions in frontend_scheduler_worker. (#5060)
  * Store metrics queueTime in seconds (#5052)
  * Docs: add an empty subsection for v2.4.2 bug fix items (#5056)
  * Chore: Remove `cortex/util/test` dependency (#5050)
  * Remove `cortex/pkg/util/extract` dependency from Loki (#5049)
  * Copy `cortex/pkg/frontend` package dependency into Loki (#5044)
  * lock the mutex before working with the `fileEventWatchers` (#5043)
  * Improve error message if incoming logs timestamp is far too behind. (#5040)
  * Loki: Implement common net interface/instance addr (#4950)
  * Improve title of the chunk dashboard. (#5041)
  * Chore: Copy `cortex/util/math` into Loki (#5036)
  * Remove unnecessary ticker in the tail loop (#5039)
  * Fix typo 'Registring'->'Registering' (#4979)
  * Promtail: exclude_user_data description fix (#5038)
  * Support Redis Cluster Configuration Endpoint (#4947)
  * Update hack_operator_make_run.md (#5025)
  * Log time in queue per request (#4949)
  * Pre-allocate chunk buffer size (#4884)
  * Docs: revise block names (ring and filesystem) and correct spelling (#5015)
  * temporary fix for the ruler joining the ingester ring (#4968)
  * feat(docs): auto assign type/docs label to docs project (#5032)
  * Chore: use `spanlogger` from `dskit` (#5029)
  * Docs: improve Promtail installation prose (#5017)
  * [new feature] logql: extrapolate unwrapped rate function (#5013)
  * Allow to disable http2 for GCS. (#4942)
  * Add distributor ring page (#4938)
  * adds instrumentation to azure object client (#5022)
  * Copy `cortex/pkg/scheduler` package dependency into Loki (#4962)
  * Copy `cortex/pkg/ruler/rulestorage` package dependency into Loki (#4978)
  * Copy `cortex/pkg/distributor` package dependency into Loki (#4983)
  * Add doc for limit param max_concurrent_tail_requests (#5011)
  * Copy `cortex/pkg/querier/astmapper` package dependency into Loki (#4982)
  * Move querier.split-queries-by-interval to a per-tenant configuration (#5023)
  * Docs: SSD mode read target runs the compactor (#5016)
  * Remove querier.query-ingesters-within check when sharding is enabled (#5024)
  * docs: fix yaml grammar mistakes (#5027)
  * fix splitting of queries when step is larger than split interval (#5006)
  * update promtail daemonset docs (#4946)
  * Docs: Fix parent of wal and wal_cleaner in loki ruler config docs (#4993)
  * Move `min_sharding_lookback` to the right place. (#5007)
  * Docs: Fix list of Ruler supported storages (#5008)
  * Update syslog receiver documentation (#5003)
  * Docs: add initial descriptions of Loki use of hash rings (#4900)
  * Add default tags for docker-compose (#4916)
  * Update _index.md (#4893)
  * Docs: fix callouts for images in the Deployment modes section (#4992)
  * update docs preview commands (#4955)
  * Provide saner default for loki-operator managed chunk_target_size (#4975)
  * Fix logo on operator README.md (#4984)
  * add docker compose example for simple scalable mode (#4876)
  * Fix operator entrypoint markdown files (#4976)
  * Provide optional matchers to `LabelValuesForMetricName`. (#4933)
  * Fix operator images actions for bundle and calculator (#4973)
  * Copy `cortex/util/fakeauth` package dependency into Loki (#4956)
  * Provide saner defaults for loki-operator reconciled config (#4963)
  * Fix failing operator github actions (#4966)
  * Fix operator action for sending code coverage (#4965)
  * Fix operator actions branch protection from master to main (#4964)
  * Move `cortex/pkg/tenant` dependency to Loki. (#4944)
  * Switch provider from Red Hat to Grafana Loki SIG operator
  * Switch API group from openshift.io to grafana.com
  * Add missing index-gateway to pod status map
  * Remove ViaQ from source code and manifests
  * Prune ViaQ references from documentation resources
  * Remove old license references
  * Make `go test` command replaceable in Makefile (#4934)
  * Correctly use limits middleware in series query (#4929)
  * Add copyright notice (#4898)
  * feat(): add ManagedIdentity in Azure Blob Storage (#4858)
  * Update logstash dependency in logstash-output-loki plugin (#4930)
  * Document correct filesystem config options in reference (#4928)
  * Skip middleware for unsupported type (#4924)
  * Docs: Fix comment in Loki module loading for accuracy (#4926)
  * Add `-list-targets` command line flag (#4920)
  * Remove duplicated code in ruler rule validation (#4903)
  * ingester: use consistent set of instances (#4904)
  * Fixes 500 when query is outside of max_query_lookback (#4902)
  * dashboards: fix typo in row title (#4894)
  * Update hedgedhttp to v0.7.0 (#4892)
  * Docs: Reorganize architecture section (#4873)
  * Fix shellcheck issues
  * Move github actions to top-level github directory
  * Switch license to AGPL v3
  * Revert "Adding PR gatekeeper (#4869)" (#4880)
  * LOG-1894: Update Loki Operand to 2.4.1 (#106)
  * add multiline to stages overview (#4851)
  * always apply replication factor common config (#4875)
  * Fix replace missing adjacent capture groups (#4874)
  * stats were logged without a log level making them not correctly filterable. (#4872)
  * LOG-1947: Provide Dev Preview Docs on how to use `make run` on loki-operator (#107)
  * Promtail pull cloudflare logs (#4813)
  * Adding PR gatekeeper (#4869)
  * Add rate limiting and metrics to hedging (#4860)
  * Fix duplicate registry.MustRegister call in Promtail Kafka (#4866)
  * Change error responses from plain text to JSON (#4845)
  * recreate compacted boltdb files from compactor when they are more than 12 hours old (#4853)
  * fixes for operational and promtail dashboard (#4856)
  * Simplify chunks dashboard label selectors + port some more internal (#4850)
  * log the user ID in the rate limit error message. (#4852)
  * Lint Loki and Promtail mixins. (#4848)
  * Adds the ability to hedge storage requests. (#4826)
  * Correctly set string in env variable in jsonnet (#4847)
  * Allow to set JAEGER_REPORTER_MAX_QUEUE_SIZE globally. (#4843)
  * Reduce tracing spans (#4842)
  * Allow for setting of per-tenant runtime configs (#4840)
  * Set alert to fire after 15m, to match message (#4839)
  * Loki mixin: Add grafonnet-lib as dependency (#4811)
  * Use http prefix path correctly in promtail (#4832)
  * Use dependabot to keep gomod dependancies up to date. (#4834)
  * Add a stat panel function so we can more easily create grid layouts via (#4836)
  * Refactor pkg/util/server to avoid cortexpb import in downstream projects vendoring logql (#4833)
  * Improve LogQL format stages requireLabel (#4769)
  * Loki: Implement custom /config handler (#4785)
  * Refactor tests of Promtail filetarget (#4802)
  * Add LabelFilterer and Store wrapper (#4818)
  * Upgrade Cortex, Prometheus and Thanos (#4830)
  * Add support for `X-Query-Tags` (#4814)
  * Enhance logging on timeout tailing logs on canary (#4825)
  * LOG-1874: lokistack-gateway component restarting too many times on OpenShift (#100)
  * Set correct `Content-Type` header in query response (#4828)
  * Use common args in compactor and index-gateway (#4824)
  * Fix up a merge conflict on log filter (#4815)
  * [doc] wal: fix default value (#4810)
  * LOG 1838: Adding Promtail, Fluentd, and Openshift Logging docs (#104)
  * Do not run manifest and deploy jobs in cron. (#4772)
  * Refactor dashboard utils to include a separate function per template (#4807)
  * [doc]: Update URL for LokiLogger.jl (Julia client) (#4784)
  * [Hot Fix] Merge improving case sensitive search correctly (#4804)
  * Improve case insensitive search to avoid allocations. (#4394)
  * Aggregate inotify watcher to file target manager (#4794)
  * Docs: Modify label names of configuration blocks (#4787)
  * LOG-1840: Dev Preview Docs on how to get started with hacking on loki-operator (#99)
  * Improve heap iterators. (#4731)
  * Expose Kafka message key in labels (#4745)
  * Make `*` and `+` non-greedy to double regex filter speed. (#4775)
  * Minor operational dashboard improvements + fix missing log template (#4780)
  * add logging in querier when live tailing request starts and ends (#4783)
  * Logql `stdin` support only log queries (#4606)
  * Docs: fix broken links (#4770)
  * Run all benchmarks. (#4742)
  * Only run benchmarks on `loki-bench` cron. (#4753)
  * LOG-1955: Dev Preview Doc to install storage size calculator on OpenShift (#105)
  * Adding upgrade guide for recording rules (#4751)
  * Enrich WAL folder creation error message (#4705)
  * Loki: Set querier worker max concurrent regardless of run configuration. (#4761)
  * Docs: inject newlines into knob descriptions to avoid horizontal scroll bar (#4733)
  * Removes all GRPC warning. (#4757)
  * Add storage size calculator (#95)
  * Promtail: improve GCP labels (#4628)
  * index cleanup fixes while applying retention (#4741)
  * Add northflank to the adopters list (#4729)
  * Add GELF support for Promtail. (#4744)
  * Give more context to rule parser errors. (#4730)
  * Join contain filters into one. (#4528)
  * allow applying retention at different interval than compaction with a config (#4736)
  * Improves memchunk benchmark to account for block size. (#4645)
  * Simplify chunk flush rate %% query. (#4711)
  * Refactor and simplify stats package. (#4712)
  * ensures components with required SRV lookups use the correct port  (#4737)
  * Docs: Fix a typo (#4726)
  * Fixes Promtail User-Agent. (#4716)
  * Docs: small v2.4.1 release notes edits (#4718)
  * Add SASL&mTLS authentication support for Kafka in Promtail (#4663)
  * Only execute benchmarks on main. (#4710)
  * Run benchmarks in cron jobs. (#4636)
  * update everything for 2.4.1 (#4701)
  * fix flaky retention tests (#4697)
  * Project: Loki 2.4.1 release notes (#4688)
  * Adds replication_factor doc to common config (#4683)
  * overrides checks for nil tenant limits on AllByUserID (#4687)
  * Loki: check new Read target when initializing boltdb-shipper store (#4681)
  * Docs: revise v2.4 release notes (#4675)
  * update references to new 2.4.0 image (#4672)
  * 2.4 release notes, changelog, upgrade guide (#4658)
  * Update local and docker config for simple scalable deployment (#4660)
  * Docs: Document the common ring section (#4664)
  * Document duplicated protos warning occurence. (#4650)
  * Fix dskit/ring metric with 'cortex_' prefix (#4656)
  * Add a test to verify goroutine leak in compression pools. (#4653)
  * no longer publish `latest` tag on every push to main (#4651)
  * Instrument s3 client DeleteObject requests. (#4649)
  * Fix local kind deployments (#101)
  * Add gh pages (#98)
  * Fix upstream calls to Loki using server-side TLS when provided (#97)
  * Fix olm-based deployments on openshift (#96)
  * Move image tag v0.0.1
  * Add OpenShift Auth native support (#94)
  * Add support for openshift-logging tenant mode (#93)
  * Disable multi-arch builds
  * Create codeql-analysis.yml
  * Add support for dependabot our GH actions (#92)
  * Make Dockerfile compatible for multi-platform builds (#91)
  * Add multiple platforms (#89)
  * Fix target registry for docker-push-action (#88)
  * Fix latest tags for push to quay action (#87)
  * Move to docker-push-action@v2 (#86)
  * Fix wrong field in push to quay action (#85)
  * Use docker/build-push-action@v1 (#84)
  * Publish images to quay.io (#83)
  * Fix go mod sum (#82)
  * Add lokistack-gateway configuration (#77)
  * Remove vendor dir (#81)
  * Add template tests for loki config and runtime config (#80)
  * fix minio deployment (#79)
  * fix send coverage workflow (#78)
  * use URI Scheme HTTPS when tls flag is provided (#75)
  * Add lokistack-gateway deployment (#65)
  * Add profiler support (#74)
  * Bump operator-sdk v1.11.0 and ctrl-runtime 0.9.2 (#73)
  * fix manifests and mutate function (#72)
  * fix issues in example secret + add LOKI_BUCKET_NAME as configurable environment variable (#67)
  * fix scorecard (#66)
  * Fix broker to read a CR and generate manifests (#64)
  * removed manual apply and delete of servicemonitor resource (#62)
  * Log 1403: OCP Certificate Signing (#59)
  * Fix minor glitches and tidy modules (#61)
  * added service monitor for ocp prometheus to scrape metrics (#58)
  * Fix query path configuration (#60)
  * Separate openshift from native k8s production overlays (#55)
  * Creating telemetry metrics for loki operator based on complete build spec (#32)
  * Set lokistack condition failed/pending/ready based on pod status map (#53)
  * Add support for a per component pod status map (#50)
  * add CONTRIBUTING.md (#54)
  * Set query frontend replicas based on selected stack size (#52)
  * Provide CSV markers to display CRD fields properly in OpenShift Console (#49)
  * LOG-1289: set pvc quotas per size (#51)
  * [API-CHANGE] Remove field MaxStreamsPerTenant in favor of using only MaxGlobalStreamsPerTenant (#48)
  * Log 1318: Adding scorecard ci test (#46)
  * Add support for runtime config (#45)
  * Allowing controller to access secrets (#44)
  * Add owner watches for LokiStack owned resources (#42)
  * Provide sane defaults for limits per stack size and loki config (#43)
  * Use pointers for optional API fields (#41)
  * Add config map hash annotation for restarting components (#35)
  * remove parallel testing of internal/management/state/state_test.go (#40)
  * Streamline API terms based on enhancement proposal (#37)
  * LOG-1247: add node selectors support (#39)
  * LOG-1247: add support for tolerations (#38)
  * Add missing manifests tests (#36)
  * Add support for compactor (#30)
  * Add reconciliation for the s3 object storage secret (#33)
  * implement t-shirt sizes (#28)
  * Provide handler for LokiStack create and update events (#27)
  * add some tests to verify services will match pods (#29)
  * Fix default CSV sample (#31)
  * Use RELATED_IMAGE_LOKI for operand img pinning on production builds (#26)
  * center image on readme (#25)
  * Split default target into development and production overlays (#24)
  * Remove legacy manifests generation (#23)
  * Add the scaffolding for tshirt sizing (#21)
  * update readme with some instructions for development (#22)
  * Ensure bundle dependencies are overwritable bei env (#20)
  * Add support to install the operator via OLM in OCP clusters (#17)
  * fix make bundle (#18)
  * Add API for the Loki stack (#15)
  * LOG-1251/convert to statefulsets (#16)
  * Add operator-sdk to bingo targets (#14)
  * add bingo (#12)
  * fix missing error return (#11)
  * make lint a non-requirement for specific make targets (#10)
  * CI: add build targets for broker and operator (#9)
  * LOG-1241: create cli for generating manifests (#8)
  * better ci and fix make (#7)
  * rename github workflow to make more sense (#6)
  * add TestCreateLokiStack_WhenGetReturnsNotFound_DoesNotError (#5)
  * CI: split coverage and lint and try to fix coverage (#4)
  * Create LICENSE.txt
  * gofmt internal/handlers/lokistack_create_test.go
  * add README.md
  * fix golangci-lint timeout flag
  * increase golangci-lint timeout to 5m
  * add golangci-lint, github actions
  * add some tests
  * move things out of the controller and into a handler
  * set ownerRefs
  * maintenance
  * rename things
  * add hack/addons.yaml for promtail and logcli
  * cleanup
  * create querier, and querier frontend
  * fix memberlist resolution
  * fix rbac generation, etc
  * working with struct definitions
  * wip
  * kustomize/v1/base/{ => config}/loki-config.yaml
  * working stack with promtail for testing
  * kustomize
  * WIP
  * init
  * init
- Use BuildRequires: golang(API) = 1.17 instead of >=,
  because with go1.18 it stop mmediately and rise up an error:
  "panic: Something in this program imports go4.org/unsafe/assume-no-moving-gc to declare that it
  assumes a non-moving garbage collector, but your version of go4.org/unsafe/assume-no-moving-gc
  hasn't been updated to assert that it's safe against the go1.18 runtime. If you want to risk it,
  run with environment variable ASSUME_NO_MOVING_GC_UNSAFE_RISK_IT_WITH=go1.18 set.
  Notably, if go1.18 adds a moving garbage collector, this program is unsafe to use."
* Thu Jan 27 2022 ecsos@opensuse.org
- Update to version 2.4.2+git.1642005974.525040a32:
  * fix merge conflict (#5120)
  * Docs: Fix documentation with correct default values and add missing options (#4792) (#5115)
  * Backport 5077: improve default config values (#5077) (#5104)
  * Loki: Implement custom /config handler (#4785) (#5078)
  * temporary fix for the ruler joining the ingester ring (#4968) (#5037)
  * Backport to 2.4: always apply replication factor common config (#4875) (#4989)
  * Docs: fix broken links (#4770) (#4778)
  * Adding upgrade guide for recording rules (#4751) (#4763)
  * Docs: inject newlines into knob descriptions to avoid horizontal scroll bar (#4733) (#4758)
  * Docs: small v2.4.1 release notes edits (#4718) (#4719)
  * update everything for 2.4.1 (#4701) (#4702)
* Mon Dec 13 2021 ecsos <ecsos@opensuse.org>
- Change user in promtail.service from loki to root.
  Without run as root promtail can not tail logfiles.
* Mon Dec 13 2021 ecsos@opensuse.org
- Update to version 2.4.1+git.1636374074.f61a4d261:
  * fix flaky retention tests (#4697) (#4698)
  * Project: Loki 2.4.1 release notes (#4688) (#4692)
  * Adds replication_factor doc to common config (#4683) (#4691)
  * overrides checks for nil tenant limits on AllByUserID (#4687) (#4690)
  * Loki: check new Read target when initializing boltdb-shipper store (#4681) (#4689)
  * remove my text to test PR push (#4678)
  * testing docs publish
  * change branch publish pr runs on
  * Docs: revise v2.4 release notes (#4675) (#4676)
  * update references to new 2.4.0 image (#4672) (#4673)
* Sun Dec 12 2021 Robert Munteanu <rombert@apache.org>
- Move the logcli tool in a separate package, to allow users to install it
  without pulling in the full loki package
* Wed Oct  6 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_promtail.service.patch
  Modified:
  * loki.service
  * promtail.service
* Fri Jun 25 2021 Stefano Torresi <stefano.torresi@suse.com>
- Fix config fillup
* Fri May 28 2021 Stefano Torresi <stefano.torresi@suse.com>
- Update to upstream version 2.2.1
* Tue May 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Split Loki server and Promtail client into separate packages
* Tue Dec  8 2020 Bogdano Arendartchuk <BArendartchuk@suse.com>
- .service: Fix CONFIG_FILE to expand mid-word
* Mon Nov  9 2020 Stefano Torresi <stefano.torresi@suse.com>
- Update packaging
  * avoid systemd and shadow hard requirements
  * use systemd-sysusers to configure the user in a dedicated 'system-user-loki' subpackage
- Update to upstream version v2.0.0
* Wed Sep  2 2020 Stefano Torresi <stefano.torresi@suse.com>
- Install binaries in /usr/bin instead of /usr/sbin since they're supposed to be ran by an unprivileged user.
* Thu May 28 2020 dmaiocchi@suse.com
- Update to version 1.5.0:
  * Prep 1.5.0 release (#2098)
  * updates loki config examples (#2097)
  * Adds backtick for the quoted string token lexer. (#2095)
  * Fixes unit in stats request log. (#2093)
  * allow no encoding/compression on chunks (#2088)
  * Accept suffixes to pod name in instance labels (#2080)
  * removes yolostring (#2078)
  * fluentd plugin: support placeholders in tenant field (#2074)
  * Fixes a panic in dry-run when using external labels. (#2075)
  * Allows to pass inlined pipeline stages to the docker driver. (#2076)
  * Loki: Allow configuring query_store_max_look_back_period when running a filesystem store and boltdb-shipper (#2073)
  * expand the match_all to also optionally allow counting bytes per stream (#2066)
  * some metrics for measuring performance and failures in boltdb shipper (#2034)
  * output a debug log if the requested path in the scrape config doesn't match any files (#2069)
  * Targets not required in promtail config (#2026)
  * Update loki to cortex master (#2030)
  * Reverse entry iterator pool (#2064)
  * Improve protobuf serialization (#2031)
  * Recover from panic in http and grpc handlers. (#2059)
  * Docker driver: Allow to provision external pipeline files to plugin (#2054)
  * Fix a bug in range vector skipping data. (#2058)
  * Docs: update Loki Helm Chart document to support Helm 3 (#2038)
  * Fix promtail client default values (#2049)
  * Fix spelling of per second (#2055)
  * Update api.md (#2056)
  * Chore: Correct typo "per seconds" (#2050)
  * Fix bug in logql parsing that leads to crash. (#2046)
  * fixes the cpu usage graphs (#2044)
  * Add extraOutputs variable to support multiple outputs for fluent-bit (#2040)
  * Swapped to container restarts over terminated reasons (#2043)
  * Remove generated comment at top of .drone/drone.yaml (#2042)
  * Dashboard: Loki Operational improvements (#2041)
  * Support Post request in the frontend queryrange handler. (#2023)
  * fluent-plugin-loki: Restructuring and CI (#2006)
  * Revert "Update go from 1.13 to 1.14. (#2013)" (#2028)
  * Update go from 1.13 to 1.14. (#2013)
  * Adds :delegated flags to speed up build experience on MacOS. (#2009)
  * logcli: Query needs to be stored into url.RawQuery, and not url.Path (#2027)
  * more linter fixes (#2024)
  * I <3 you Linter (#2022)
  * Docs: Added labels content (#1999)
  * Loki: refactor validation and improve error messages (#2021)
  * Spelling (#2014)
  * Change image tag from 1.4.1 to 1.4.0 in Helm chart (#2015)
  * Update lz4 library to latest to ensure deterministic output. (#2010)
  * make `loki_ingester_memory_streams` Gauge per tenant. (#2019)
  * Loki: Improve logging and add metrics to streams dropped by stream limit (#2012)
  * Fix a bad rebase between #1970 and #1965. (#2011)
  * Adds config to disable HTTP and GRPC server in Promtail. (#2004)
  * Allow to aggregate binary operations. (#1970)
  * table client for boltdb shipper to enforce retention (#2001)
  * Improve URL building in the logcli to strip trailing /. (#2000)
  * Ensure trace propagation in our logs. (#1977)
  * Loki: Adds an `interval` paramater to query_range queries allowing a sampling of events to be returned based on the provided interval (#1965)
  * make boltdb shipper singleton and some other minor refactoring (#1995)
  * Update cortex to latest. (#1982)
  * Add a missing method to facade which is called by the metrics storage client in cortex (#1987)
  * added extraCommandlineArgs in values file (#1981)
  * Log error message for invalid checksum (#1713)
  * Log slow query from the frontend by default in ksonnet. (#1980)
  * incorporate some better defaults into table-manager configs (#1976)
  * Update cortex vendoring to latest master (#1975)
  * [Loki]: Cleanup dockerfile (#1949)
  * Convert Loki modules to services (#1804)
  * fix available stores for chunk and index in documentation for period config (#1974)
  * Improve the local config to work locally and inside docker. (#1963)
  * helm chart: add missing line feed (#1967)
  * Docs: Update docker.md (#1966)
  * chunk bounds metric now records 8h range in 1h increments (#1964)
  * flush boltdb to object store (#1837)
  * chunk lifespan histogram (#1958)
  * Workaround for broken etcd gomod import (#1961)
  * Go mod: explicit golang.org/x/net replace (#1953)
  * Move build from source instructions to root readme. (#1951)
  * update cortex to latest master (#1956)
  * Loki Update the cut block size counter when creating a memchunk from byte slice (#1946)
  * Fixes case handling in regex simplification. (#1950)
  * Log docker driver config map. (#1903)
  * version pin the docker image in docker-compose (#1945)
  * Reverting helm changes which were included in Cortex 1.0 vendor upgrade because it resulted in us pushing an unstable helm.
  * delete tag script filters by prefix instead of substring (#1942)
  * Support stdin target via flag instead of automatic detection. (#1935)
  * adds config validation, similar to cortex (#1939)
  * bumps helm to keepalive-master after cortex vendoring (#1937)
  * Update Cortex to latest master (#1869)
  * Add no-file and keep-file log option for docker driver. (#1906)
  * logcli: org-id/tls-skip-verify set via env var (#1922)
  * Clarified that the api push path needs to be specified. (#1925)
  * And the loki mixin
  * Put loki-mixin and promtail-mixin dashboards in a folder.
  * feat: tms readiness check bypass implementation
  * this Dockerfile is a remnant from a long time ago, not needed. (#1918)
  * only fetches one chunk per series in /series (#1914)
  * Add cap_net_bind_service linux capabilities to Loki. (#1916)
  * Fix fluent-bit metrics (#1915)
  * s/dashboards/grafanaDashboards.
  * fluentd loki plugin README: add note about labels (#1909)
  * push images for `k` branches
  * updating typo for end time parameter (#1905)
  * updating helm and ksonnet to 1.4.1 updating Fluent Bit to correct image
  * JSON encoding: avoid base64 encoding of []byte inside other slices (#1890)
  * [helm loki/promtail] make UpdateStrategy configurable (#1898)
  * Addition of a `/suspend` endpoint to Loki Canary (#1891)
  * Removes file size check for pipe, not provided by linux. (#1893)
  * Fixes possible panic in json pipeline stage. (#1894)
  * Fix flaky promtail test (#1865)
  * docs: cleaning up the comments for the cache_config, default_validity option (#1888)
  * Adding a config change in release 1.4 upgrade doc Updating readme with links to new docs
  * Sign helm package with GPG. (#1864)
  * Add precision about the range notation for LogQL. (#1881)
  * updating helm and ksonnet for 1.4.0 release
  * clear out some changelog entries to fix a merge conflict from the release branch
  * docs: update promtail docs for backoff (#1879)
  * Support series API in logcli (#1861)
  * support `match[]` encoding (#1875)
  * Keep plugin install command example in one line (#1870)
  * Add extraMount, extraVolumeMount to promtail helm chart for systemd-journal (#1871)
  * documents frontend worker (#1873)
  * clarify logcli commands and output (#1712)
  * Logcli remote storage. (#1814)
  * Sharding optimizations I: AST mapping (#1846)
  * docs: tweak the doc section of the readme a little (#1856)
  * Support configurable maximum of the limits parameter (#1798)
  * bump gem version (#1853)
  * throw exceptions on HTTPTooManyRequests and HTTPServerError so FluentD will retry (#1845)
  * logcli client: use OrgID in LiveTail (#1850)
  * remove a few places we recommend the schema version and consolidate in the configuration doc
  * Pin helm version in circle-ci helm testing workflow. (#1849)
  * Proposal: Promtail Push API (#1627)
  * promtail retry 429 rate limit errors, clarifying risks in the docs of configuring multiple client sections in promtail, also increased the backoff and retry settings in promtail.
  * Docs: Update configuration docs for redis (#1843)
  * Log error message when source does not exist in extracted values (#1815)
  * Helm/loki-stack: refresh default grafana.image.tag to 6.7.0 (#1825)
  * Move default port for Loki to 3100 everywhere. (#1838)
  * Change local storage directory to /loki/ and fix permissions (#1833) (#1834)
  * Use 8080 for Loki http port  binding in tanka. (#1823)
  * Adds a counter for total flushed chunks per reason. (#1819)
  * Prevent prometheus to scrap both services (#1817)
  * loki can not be started with loki-local-config.yaml (#1816)
  * Optimize empty filter queries. (#1810)
  * Improve fluentbit logfmt. (#1791)
  * Test stats memchunk (#1809)
  * Error handling: Show data stream at "debug" level, not "warn" (#1811)
  * loki: update Cortex to master (#1799)
  * Non-root user docker image for Loki. (#1706)
* Fri Apr 17 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Update to version 1.4.1:
  * updating changelog and version numbers in docs for 1.4.1 release
  * JSON encoding: avoid base64 encoding of []byte inside other slices (#1890)
  * Removes file size check for pipe, not provided by linux. (#1893)
  * fixing release date
  * Updating some of the references to v1.3.0 Adding an entry in the changelog to reference image name changes
  * docs: update promtail docs for backoff (#1879)
  * bump gem version (#1853)
  * throw exceptions on HTTPTooManyRequests and HTTPServerError so FluentD will retry (#1845)
  * promtail retry 429 rate limit errors, clarifying risks in the docs of configuring multiple client sections in promtail, also increased the backoff and retry settings in promtail.
  * Adding upgrade doc and updating changelog for release
* Mon Jul  1 2019 JMC <jcavalheiro@suse.com>
- Add compat macro for _fillupdir to allow builds in SLE12
* Mon Jul  1 2019 João Cavalheiro <jcavalheiro@suse.com>
- Initial commit (v0.1.0)
